*GARCH Model model 
*uses three period to generate shocks
*includes political surprise variables
set more off
run option
sort obs
gen inc_smooth=con_smooth
replace inc_smooth=lab_smooth if labor==1
tsset obs
genl dx=d.luk
genl da=d.inc_smooth

reg da dx
keep if e(sample)
sort obs
drop obs
gen obs=_n
tsset obs

*keep variables and observations of interest
keep obs date da dx labor emsstep election honeymoon unemployment inflation inc_smooth
replace honeymoon=0 if honeymoon==.
replace election=0 if election==.
replace emsstep=0 if emsstep==.
gen postems=0
replace postems=1 in 403/-1
gen crisis=0
replace crisis=1 in 401/402

*create dummy variables for consequential elections and electoral surprises
gen conseq=0
gen loser=0
replace conseq=1 if inc_smooth<=45 & inc_smooth>=35
replace loser=1 if inc_smooth<35
gen ACps=.
gen ACns=.
gen ALps=.
gen ALns=.

gen XCps=.
gen XCns=.
gen XLps=.
gen XLns=.

*hold predictions
gen Axb=.
gen Ast=.
gen Xxb=.
gen Xst=.
gen Xup=.
gen Xlo=.
gen Aup=.
gen Alo=.

*Volatility
gen V=.
gen LV=.
gen CV=.
gen v=.
gen Cv=.
gen Lv=.


*estimate model on first 100 observations to get initial values
*approval model
reg da l.da l2.da l.dx l2.dx election honeymoon dl.unemp dl.inflat in 1/102
predict axb if e(sample), xb
predict ast if e(sample), stdp
replace Aup=axb+1.96*ast
replace Alo=axb-1.96*ast
gen PAshock=da-axb if da>Aup & Aup~=.
gen NAshock=da-axb if da<Alo & Alo~=.
gen pashock=0 in 1/102
gen nashock=0 in 1/102
replace pashock=PAshock in 1/102 if PAshock~=. & l.PAshock~=. & l2.PAshock~=.
replace nashock=NAshock in 1/102 if NAshock~=. & l.NAshock~=. & l2.NAshock~=.
replace ACps=conseq*pashock in 1/102
replace ACns=conseq*nashock in 1/102
replace ALps=loser*pashock in 1/102
replace ALns=loser*nashock in 1/102

*arch model
#delimit ;
arch dx l.dx l2.dx dl.unemp dl.inflat in 1/102, arch(1) garch(1) 
het(l.pashock l.nashock l.conseq l.ACps l.ACns l.loser l.ALps l.ALns) 
nolog dfp gtolerance(999); 
#delimit cr
mat x=e(b)
predict xxb if e(sample), xb
predict xst if e(sample), stdp
predict vv if e(sample), var
replace Xup=xxb+1.96*xst
replace Xlo=xxb-1.96*xst
gen PXshock=dx-xxb if dx>Xup & Xup~=.
gen NXshock=dx-xxb if dx<Xlo & Xlo~=.
gen pxshock=0 in 1/102
gen nxshock=0 in 1/102
replace pxshock=PXshock in 1/102 if PXshock~=. & l.PXshock~=. & l2.PXshock~=.
replace nxshock=NXshock in 1/102 if NXshock~=. & l.NXshock~=. & l2.NXshock~=.
replace XCps=conseq*pxshock in 1/102
replace XCns=conseq*nxshock in 1/102
replace XLps=loser*pxshock in 1/102
replace XLns=loser*nxshock in 1/102
replace v=vv in 1/102
replace Lv=loser*v in 1/102
replace Cv=conseq*v in 1/102


drop xxb xst axb ast vv

*create loop

local a = 103
while `a' <= 859 {
	display `a'

	*APPROVAL MODEL
	rreg da l.da l2.da l.dx l2.dx l.election l.honeymoon dl.unemp dl.inflat l.pxshock l.nxshock l.v in 1/`a' 
	predict axb if e(sample),  xb
	predict ast if e(sample),  stdp
	replace Aup=axb+1.96*ast in `a'
	replace Alo=axb-1.96*ast in `a'
	replace PAshock=da-axb in `a' if da>Aup
	replace NAshock=da-axb in `a' if da<Alo
	replace pashock=PAshock in `a' if PAshock~=. & l.PAshock~=. & l2.PAshock~=.
	replace nashock=NAshock in `a' if NAshock~=. & l.NAshock~=. & l2.NAshock~=.
	replace pashock=0 in `a' if pashock==.
	replace nashock=0 in `a' if nashock==.
	replace ACps=conseq*pashock in `a'
	replace ACns=conseq*nashock in `a'
	replace ALps=loser*pashock in `a'
	replace ALns=loser*nashock in `a'


	*EXRATE MODEL
	#delimit ;
	capture arch dx l.da l2.da l.dx l2.dx l.emsstep l.postems l.crisis dl.unemp dl.inflat  in 1/`a', 
	arch(1) garch(1) het(l.emsstep l.postems l.crisis l.pashock l.nashock l.conseq l.ACps l.ACns l.loser l.ALps l.ALns)
	dfp nolog from(x,skip) gtolerance(999); 
	#delimit cr

	capture predict xxb if e(sample),  xb
	capture predict xst if e(sample),  stdp
	capture predict vv if e(sample), var

	capture replace Xup=xxb+1.96*xst in `a'
	capture replace Xlo=xxb-1.96*xst in `a'
	capture replace PXshock=dx-xxb in `a' if dx>Xup
	capture replace NXshock=dx-xxb in `a' if dx<Xlo
	capture replace pxshock=PXshock in `a' if PXshock~=. & l.PXshock~=. & l2.PXshock~=.
	capture replace nxshock=NXshock in `a' if NXshock~=. & l.NXshock~=. & l2.NXshock~=.
	capture replace pxshock=0 in `a' if pxshock==.
	capture replace nxshock=0 in `a' if nxshock==.
	capture replace XCps=conseq*pxshock in `a'
	capture replace XCns=conseq*nxshock in `a'
	capture replace XLps=loser*pxshock in `a'
	capture replace XLns=loser*nxshock in `a'
	
	*replace predictions with t-1 predictions if no convergence
	replace XCps=l.XCps in `a' if XCps==.
	replace XCns=l.XCns in `a' if XCns==.
	replace XLps=l.XLps in `a' if XLps==.
	replace XLns=l.XLns in `a' if XLns==.

	capture replace v=vv in `a'
	replace v=l.v in `a' if v==.
	replace Lv=loser*v in `a'
	replace Cv=conseq*v in `a'

	capture drop xxb
	capture drop xst
	capture drop axb
	capture drop ast
	capture drop vv
	
	local a =`a' +1
}
compress
save model2r,replace

