use combined,clear
tsset obs
sort obs
replace con_smooth=l.con_smooth if con_smooth==.
replace lab_smooth=l.lab_smooth if lab_smooth==.
replace lib_smooth=l.lib_smooth if lib_smooth==.

*gen election=0
*1987 election
replace election=1 in 645
*1992 election
replace election=1 in 897
*1997 election
replace election=1 in 1162
*2001 election
replace election=1 in 1376

*replace election=1 if year
gen called=0
*1987 election
replace called=1 in 641
*1992 election
replace called=1 in 893
*1997 election
replace called=1 in 1155
*2001 election
replace called=1 in 1372

*electoral option model
*number of days until election
*term is 5 years (260 weeks)

*labor
gen labor=0
replace labor=1 in 1163/1378

*term (begins week after election(t), ends week of election(t+1)) 
*1983-1987
gen term=1 in 438/645
*1987-1992
replace term=2 in 646/897
*1992-1997
replace term=3 in 898/1162
*1997-2001
replace term=4 in 1163/1374
*2001-
replace term=5 in 1375/1378

*generate counter to calculate number of observations used to calculate means and variances
*time is maximum number of days until next election
sort term obs
by term: gen obs2=_n
sort obs
gen time=260-obs2

*LABOR
*TERM1
*generate cumulative mean
gen sum_lab=sum(d.lab_smooth) if term==1
gen mean_lab=sum_lab/obs2 if term==1

*generate moving variance
gen dev2_lab=(d.lab_smooth-mean_lab)^2  if term==1
gen sumdev2_lab=sum(dev2_lab) if term==1 
gen var_lab=sumdev2/(obs2-1) if term==1

*generate moving standard deviation
gen sd_lab=sqrt(var_lab) if term==1

*calculate measures for option model
gen lab1_nprob50=norm((lab_smooth+(mean_lab*time)-50)/(sd_lab*(sqrt(time)))) if term==1
gen lab1_nprob40=norm((lab_smooth+(mean_lab*time)-40)/(sd_lab*(sqrt(time)))) if term==1
gen lab1_nprob43=norm((lab_smooth+(mean_lab*time)-43)/(sd_lab*(sqrt(time)))) if term==1

drop  sum_lab mean_lab dev2_lab sumdev2_lab var_lab sd_lab


*TERM2
*generate cumulative mean
gen sum_lab=sum(d.lab_smooth) if term==2
gen mean_lab=sum_lab/obs2 if term==2

*generate moving variance
gen dev2_lab=(d.lab_smooth-mean_lab)^2  if term==2
gen sumdev2_lab=sum(dev2_lab) if term==2
gen var_lab=sumdev2/(obs2-1) if term==2

*generate moving standard deviation
gen sd_lab=sqrt(var_lab) if term==2

*calculate measures for option model
gen lab2_nprob50=norm((lab_smooth+(mean_lab*time)-50)/(sd_lab*(sqrt(time)))) if term==2
gen lab2_nprob40=norm((lab_smooth+(mean_lab*time)-40)/(sd_lab*(sqrt(time)))) if term==2
gen lab2_nprob43=norm((lab_smooth+(mean_lab*time)-43)/(sd_lab*(sqrt(time)))) if term==2

drop  sum_lab mean_lab dev2_lab sumdev2_lab var_lab sd_lab

*TERM3
*generate cumulative mean
gen sum_lab=sum(d.lab_smooth) if term==3
gen mean_lab=sum_lab/obs2 if term==3

*generate moving variance
gen dev2_lab=(d.lab_smooth-mean_lab)^2  if term==3
gen sumdev2_lab=sum(dev2_lab) if term==3
gen var_lab=sumdev2/(obs2-1) if term==3

*generate moving standard deviation
gen sd_lab=sqrt(var_lab) if term==3

*calculate measures for option model
gen lab3_nprob50=norm((lab_smooth+(mean_lab*time)-50)/(sd_lab*(sqrt(time)))) if term==3
gen lab3_nprob40=norm((lab_smooth+(mean_lab*time)-40)/(sd_lab*(sqrt(time)))) if term==3
gen lab3_nprob43=norm((lab_smooth+(mean_lab*time)-43)/(sd_lab*(sqrt(time)))) if term==3

drop  sum_lab mean_lab dev2_lab sumdev2_lab var_lab sd_lab

*TERM4
*generate cumulative mean
gen sum_lab=sum(d.lab_smooth) if term==4
gen mean_lab=sum_lab/obs2 if term==4

*generate moving variance
gen dev2_lab=(d.lab_smooth-mean_lab)^2  if term==4
gen sumdev2_lab=sum(dev2_lab) if term==4
gen var_lab=sumdev2/(obs2-1) if term==4

*generate moving standard deviation
gen sd_lab=sqrt(var_lab) if term==4

*calculate measures for option model
gen lab4_nprob50=norm((lab_smooth+(mean_lab*time)-50)/(sd_lab*(sqrt(time)))) if term==4
gen lab4_nprob40=norm((lab_smooth+(mean_lab*time)-40)/(sd_lab*(sqrt(time)))) if term==4
gen lab4_nprob43=norm((lab_smooth+(mean_lab*time)-43)/(sd_lab*(sqrt(time)))) if term==4

drop  sum_lab mean_lab dev2_lab sumdev2_lab var_lab sd_lab

*TERM5
*generate cumulative mean
gen sum_lab=sum(d.lab_smooth) if term==5
gen mean_lab=sum_lab/obs2 if term==5

*generate moving variance
gen dev2_lab=(d.lab_smooth-mean_lab)^2  if term==5
gen sumdev2_lab=sum(dev2_lab) if term==5
gen var_lab=sumdev2/(obs2-1) if term==5

*generate moving standard deviation
gen sd_lab=sqrt(var_lab) if term==5

*calculate measures for option model
gen lab5_nprob50=norm((lab_smooth+(mean_lab*time)-50)/(sd_lab*(sqrt(time)))) if term==5
gen lab5_nprob40=norm((lab_smooth+(mean_lab*time)-40)/(sd_lab*(sqrt(time)))) if term==5
gen lab5_nprob43=norm((lab_smooth+(mean_lab*time)-43)/(sd_lab*(sqrt(time)))) if term==5

drop  sum_lab mean_lab dev2_lab sumdev2_lab var_lab sd_lab

gen lab43=lab1_nprob43
replace lab43=lab2_nprob43 if lab43==.
replace lab43=lab3_nprob43 if lab43==.
replace lab43=lab4_nprob43 if lab43==.
replace lab43=lab5_nprob43 if lab43==.

gen e_lab43=1-((4*(lab43-.5)^2))


*************************************************************************************************

*LIB
*TERM1
*generate cumulative mean
gen sum_lib=sum(d.lib_smooth) if term==1
gen mean_lib=sum_lib/obs2 if term==1

*generate moving variance
gen dev2_lib=(d.lib_smooth-mean_lib)^2  if term==1
gen sumdev2_lib=sum(dev2_lib) if term==1
gen var_lib=sumdev2/(obs2-1) if term==1

*generate moving standard deviation
gen sd_lib=sqrt(var_lib) if term==1

*calculate measures for option model
gen lib1_nprob50=norm((lib_smooth+(mean_lib*time)-50)/(sd_lib*(sqrt(time)))) if term==1
gen lib1_nprob40=norm((lib_smooth+(mean_lib*time)-40)/(sd_lib*(sqrt(time)))) if term==1
gen lib1_nprob43=norm((lib_smooth+(mean_lib*time)-43)/(sd_lib*(sqrt(time)))) if term==1

drop  sum_lib mean_lib dev2_lib sumdev2_lib var_lib sd_lib


*TERM2
*generate cumulative mean
gen sum_lib=sum(d.lib_smooth) if term==2
gen mean_lib=sum_lib/obs2 if term==2

*generate moving variance
gen dev2_lib=(d.lib_smooth-mean_lib)^2  if term==2
gen sumdev2_lib=sum(dev2_lib) if term==2
gen var_lib=sumdev2/(obs2-1) if term==2

*generate moving standard deviation
gen sd_lib=sqrt(var_lib) if term==2

*calculate measures for option model
gen lib2_nprob50=norm((lib_smooth+(mean_lib*time)-50)/(sd_lib*(sqrt(time)))) if term==2
gen lib2_nprob40=norm((lib_smooth+(mean_lib*time)-40)/(sd_lib*(sqrt(time)))) if term==2
gen lib2_nprob43=norm((lib_smooth+(mean_lib*time)-43)/(sd_lib*(sqrt(time)))) if term==2

drop  sum_lib mean_lib dev2_lib sumdev2_lib var_lib sd_lib

*TERM3
*generate cumulative mean
gen sum_lib=sum(d.lib_smooth) if term==3
gen mean_lib=sum_lib/obs2 if term==3

*generate moving variance
gen dev2_lib=(d.lib_smooth-mean_lib)^2  if term==3
gen sumdev2_lib=sum(dev2_lib) if term==3
gen var_lib=sumdev2/(obs2-1) if term==3

*generate moving standard deviation
gen sd_lib=sqrt(var_lib) if term==3

*calculate measures for option model
gen lib3_nprob50=norm((lib_smooth+(mean_lib*time)-50)/(sd_lib*(sqrt(time)))) if term==3
gen lib3_nprob40=norm((lib_smooth+(mean_lib*time)-40)/(sd_lib*(sqrt(time)))) if term==3
gen lib3_nprob43=norm((lib_smooth+(mean_lib*time)-43)/(sd_lib*(sqrt(time)))) if term==3

drop  sum_lib mean_lib dev2_lib sumdev2_lib var_lib sd_lib

*TERM4
*generate cumulative mean
gen sum_lib=sum(d.lib_smooth) if term==4
gen mean_lib=sum_lib/obs2 if term==4

*generate moving variance
gen dev2_lib=(d.lib_smooth-mean_lib)^2  if term==4
gen sumdev2_lib=sum(dev2_lib) if term==4
gen var_lib=sumdev2/(obs2-1) if term==4

*generate moving standard deviation
gen sd_lib=sqrt(var_lib) if term==4

*calculate measures for option model
gen lib4_nprob50=norm((lib_smooth+(mean_lib*time)-50)/(sd_lib*(sqrt(time)))) if term==4
gen lib4_nprob40=norm((lib_smooth+(mean_lib*time)-40)/(sd_lib*(sqrt(time)))) if term==4
gen lib4_nprob43=norm((lib_smooth+(mean_lib*time)-43)/(sd_lib*(sqrt(time)))) if term==4

drop  sum_lib mean_lib dev2_lib sumdev2_lib var_lib sd_lib

*TERM5
*generate cumulative mean
gen sum_lib=sum(d.lib_smooth) if term==5
gen mean_lib=sum_lib/obs2 if term==5

*generate moving variance
gen dev2_lib=(d.lib_smooth-mean_lib)^2  if term==5
gen sumdev2_lib=sum(dev2_lib) if term==5
gen var_lib=sumdev2/(obs2-1) if term==5

*generate moving standard deviation
gen sd_lib=sqrt(var_lib) if term==5

*calculate measures for option model
gen lib5_nprob50=norm((lib_smooth+(mean_lib*time)-50)/(sd_lib*(sqrt(time)))) if term==5
gen lib5_nprob40=norm((lib_smooth+(mean_lib*time)-40)/(sd_lib*(sqrt(time)))) if term==5
gen lib5_nprob43=norm((lib_smooth+(mean_lib*time)-43)/(sd_lib*(sqrt(time)))) if term==5

drop  sum_lib mean_lib dev2_lib sumdev2_lib var_lib sd_lib

gen lib43=lib1_nprob43
replace lib43=lib2_nprob43 if lib43==.
replace lib43=lib3_nprob43 if lib43==.
replace lib43=lib4_nprob43 if lib43==.
replace lib43=lib5_nprob43 if lib43==.

gen e_lib43=1-((4*(lib43-.5)^2))

***********************************************************************************************************

*CON
*TERM1
*generate cumulative mean
gen sum_con=sum(d.con_smooth) if term==1
gen mean_con=sum_con/obs2 if term==1

*generate moving variance
gen dev2_con=(d.con_smooth-mean_con)^2  if term==1
gen sumdev2_con=sum(dev2_con) if term==1
gen var_con=sumdev2/(obs2-1) if term==1

*generate moving standard deviation
gen sd_con=sqrt(var_con) if term==1

*calculate measures for option model
gen con1_nprob50=norm((con_smooth+(mean_con*time)-50)/(sd_con*(sqrt(time)))) if term==1
gen con1_nprob40=norm((con_smooth+(mean_con*time)-40)/(sd_con*(sqrt(time)))) if term==1
gen con1_nprob43=norm((con_smooth+(mean_con*time)-43)/(sd_con*(sqrt(time)))) if term==1

drop  sum_con mean_con dev2_con sumdev2_con var_con sd_con


*TERM2
*generate cumulative mean
gen sum_con=sum(d.con_smooth) if term==2
gen mean_con=sum_con/obs2 if term==2

*generate moving variance
gen dev2_con=(d.con_smooth-mean_con)^2  if term==2
gen sumdev2_con=sum(dev2_con) if term==2
gen var_con=sumdev2/(obs2-1) if term==2

*generate moving standard deviation
gen sd_con=sqrt(var_con) if term==2

*calculate measures for option model
gen con2_nprob50=norm((con_smooth+(mean_con*time)-50)/(sd_con*(sqrt(time)))) if term==2
gen con2_nprob40=norm((con_smooth+(mean_con*time)-40)/(sd_con*(sqrt(time)))) if term==2
gen con2_nprob43=norm((con_smooth+(mean_con*time)-43)/(sd_con*(sqrt(time)))) if term==2

drop  sum_con mean_con dev2_con sumdev2_con var_con sd_con

*TERM3
*generate cumulative mean
gen sum_con=sum(d.con_smooth) if term==3
gen mean_con=sum_con/obs2 if term==3

*generate moving variance
gen dev2_con=(d.con_smooth-mean_con)^2  if term==3
gen sumdev2_con=sum(dev2_con) if term==3
gen var_con=sumdev2/(obs2-1) if term==3

*generate moving standard deviation
gen sd_con=sqrt(var_con) if term==3

*calculate measures for option model
gen con3_nprob50=norm((con_smooth+(mean_con*time)-50)/(sd_con*(sqrt(time)))) if term==3
gen con3_nprob40=norm((con_smooth+(mean_con*time)-40)/(sd_con*(sqrt(time)))) if term==3
gen con3_nprob43=norm((con_smooth+(mean_con*time)-43)/(sd_con*(sqrt(time)))) if term==3

drop  sum_con mean_con dev2_con sumdev2_con var_con sd_con

*TERM4
*generate cumulative mean
gen sum_con=sum(d.con_smooth) if term==4
gen mean_con=sum_con/obs2 if term==4

*generate moving variance
gen dev2_con=(d.con_smooth-mean_con)^2  if term==4
gen sumdev2_con=sum(dev2_con) if term==4
gen var_con=sumdev2/(obs2-1) if term==4

*generate moving standard deviation
gen sd_con=sqrt(var_con) if term==4

*calculate measures for option model
gen con4_nprob50=norm((con_smooth+(mean_con*time)-50)/(sd_con*(sqrt(time)))) if term==4
gen con4_nprob40=norm((con_smooth+(mean_con*time)-40)/(sd_con*(sqrt(time)))) if term==4
gen con4_nprob43=norm((con_smooth+(mean_con*time)-43)/(sd_con*(sqrt(time)))) if term==4

drop  sum_con mean_con dev2_con sumdev2_con var_con sd_con

*TERM5
*generate cumulative mean
gen sum_con=sum(d.con_smooth) if term==5
gen mean_con=sum_con/obs2 if term==5

*generate moving variance
gen dev2_con=(d.con_smooth-mean_con)^2  if term==5
gen sumdev2_con=sum(dev2_con) if term==5
gen var_con=sumdev2/(obs2-1) if term==5

*generate moving standard deviation
gen sd_con=sqrt(var_con) if term==5

*calculate measures for option model
gen con5_nprob50=norm((con_smooth+(mean_con*time)-50)/(sd_con*(sqrt(time)))) if term==5
gen con5_nprob40=norm((con_smooth+(mean_con*time)-40)/(sd_con*(sqrt(time)))) if term==5
gen con5_nprob43=norm((con_smooth+(mean_con*time)-43)/(sd_con*(sqrt(time)))) if term==5

drop  sum_con mean_con dev2_con sumdev2_con var_con sd_con

gen con43=con1_nprob43
replace con43=con2_nprob43 if con43==.
replace con43=con3_nprob43 if con43==.
replace con43=con4_nprob43 if con43==.
replace con43=con5_nprob43 if con43==.

gen e_con43=1-((4*(con43-.5)^2))
